@@ -1,7 +1,7 @@
 /*
  * Sudoku: A plug-in for the Video Disk Recorder
  *
- * Copyright (C) 2008, Thomas Gnther <tom@toms-cafe.de>
+ * Copyright (C) 2008-2010, Thomas Günther <tom@toms-cafe.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,12 +16,10 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * $Id: list.cpp 161 2008-11-23 00:18:02Z tom $
  */
 
 #include "list.h"
-#include "i18n.h"
+#include <vdr/i18n.h>
 #include <vdr/config.h>
 #include <vdr/osdbase.h>
 #include <vdr/osd.h>
@@ -29,12 +27,6 @@
 #include <vdr/interface.h>
 #include <assert.h>
 
-// Compatibility to older vdr versions
-#if VDRVERSNUM < 10511
-  #define cMenuEditStrItem(n, v, l) cMenuEditStrItem((n), (v), (l),\
-                                                     trVDR(FileNameChars))
-#endif
-
 using namespace SudokuPlugin;
 
 
