@@ -1,7 +1,7 @@
 /*
  * Sudoku: A plug-in for the Video Disk Recorder
  *
- * Copyright (C) 2005-2008, Thomas Gnther <tom@toms-cafe.de>
+ * Copyright (C) 2005-2010, Thomas Günther <tom@toms-cafe.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * $Id: setup.h 143 2008-07-26 18:38:59Z tom $
  */
 
 #ifndef VDR_SUDOKU_SETUP_H
@@ -48,14 +46,12 @@ namespace SudokuPlugin
     int key_red;
     int key_green;
     int key_yellow;
-#if VDRVERSNUM >= 10504
     char maxi_font[MAXFONTNAME];
     int maxi_font_height;
     int maxi_font_width;
     char mini_font[MAXFONTNAME];
     int mini_font_height;
     int mini_font_width;
-#endif
     int transparency;
 
     /** Constructor */
@@ -73,10 +69,8 @@ namespace SudokuPlugin
   {
     SetupData& setup;
     SetupData data;
-#if VDRVERSNUM >= 10504
     cStringList maxi_font_names, mini_font_names;
     int maxi_font_index, mini_font_index;
-#endif
 
   public:
 
