@@ -1,7 +1,7 @@
 /*
  * Sudoku: A plug-in for the Video Disk Recorder
  *
- * Copyright (C) 2005-2008, Thomas Gnther <tom@toms-cafe.de>
+ * Copyright (C) 2005-2008, Thomas Günther <tom@toms-cafe.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,8 +16,6 @@
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * $Id: solver.cpp 117 2008-03-21 17:57:50Z tom $
  */
 
 #define USE_RAND
@@ -46,7 +44,7 @@ Solver::Solver(Puzzle& puzzle, bool random_init, unsigned int max_iter) :
 void Solver::set_first_at(unsigned int level)
 {
   assert(level < free_count);
-  const Pos p = puzzle.next_free();
+  const Pos p = puzzle.next_cell();
   assert(p <= Pos::last());
 
   free_list[level] = p;
